module.exports = (grunt) ->
  'use strict'

  grunt.initConfig
    pkg: grunt.file.readJSON('package.json')
    copy:
      main:
        files: [
          expand: true
          cwd: 'src/'
          src: ['**/*.js']
          dest: '.gen/src/'
        ]
      test:
        files: [
          expand: true
          cwd: 'test/'
          src: ['**/*.js']
          dest: '.gen/test/'
        ]
    coffeelint:
      gruntfile:
        src: 'Gruntfile.coffee'
      src:
        src: ['src/**/*.coffee']
      test:
        src: ['test/**/*.coffee']
      options:
        no_trailing_whitespace:
          level: 'error'
        max_line_length:
          level: 'error'
    coffee:
      src:
        expand: true
        cwd: 'src/'
        src: ['**/*.coffee']
        dest: '.gen/src/'
        ext: '.js'
      test:
        expand: true
        cwd: 'test/'
        src: ['**/*.coffee']
        dest: '.gen/test/'
        ext: '.js'
    simplemocha:
      all:
        src: [
          'node_modules/should/lib/should.js'
          '.gen/test/**/*.js'
        ]
        options:
          globals: ['should']
          timeout: 3000
          ignoreLeaks: false
          ui: 'bdd'
          reporter: 'spec'
    watch:
      gruntfile:
        files: '<%= coffeelint.gruntfile.src %>'
        tasks: ['coffeelint:gruntfile']
      coffeeLib:
        files: '<%= coffeelint.src.src %>'
        tasks: ['coffeelint:src', 'coffee:src', 'simplemocha']
      coffeeTest:
        files: '<%= coffeelint.test.src %>'
        tasks: ['coffeelint:test', 'coffee:test', 'simplemocha']
    clean: ['.gen/']

    grunt.loadNpmTasks 'grunt-coffeelint'
    grunt.loadNpmTasks 'grunt-contrib-clean'
    grunt.loadNpmTasks 'grunt-contrib-coffee'
    grunt.loadNpmTasks 'grunt-contrib-copy'
    grunt.loadNpmTasks 'grunt-contrib-watch'
    grunt.loadNpmTasks 'grunt-simple-mocha'

    grunt.registerTask 'compile', [
      'coffeelint'
      'copy'
      'coffee'
    ]

    grunt.registerTask 'default', [
      'compile'
      'simplemocha'
    ]
