'use strict'
should = require 'should'
util = require 'util'

{HubotEtcdBrainListener} = require '../src'
{SupportRobot, SupportEtcd} = require './support'

describe 'HubotEtcdBrainListener', ->
  robot = new SupportRobot
  client = new SupportEtcd
  brainKey = "/test-hubot-brain/#{Math.random()}"

  beforeEach ->
    client.data = {}
    client.data[brainKey] = {
      value: JSON.stringify({users: {}, _private: {}})
    }
    robot.brain.data =
      users: {}
      _private: {}

  it 'uses injected etcd client', ->
    listener = new HubotEtcdBrainListener(brainKey, client, robot)
    should.exist(listener.client)
    listener.client.should.eql(client)

  it 'syncs to etcd client on @robot.set', (done) ->
    listener = new HubotEtcdBrainListener(brainKey, client, robot)
    doneOnce = false
    listener.on 'synced', (data) ->
      if doneOnce
        return
      should.exist(client.data[brainKey])
      JSON.parse(client.data[brainKey].value)
        ._private.derp.should.eql('herp')
      doneOnce = true
      done()
    robot.brain.set('derp', 'herp')

  it 'syncs to etcd client on @robot.save', (done) ->
    listener = new HubotEtcdBrainListener(brainKey, client, robot)
    listener.on 'saved', (data) ->
      should.exist(client.data[brainKey])
      done()
    robot.brain.save()

  it 'merges in the remote brain via loadJSON', (done) ->
    derpValue = "#{Math.random()}"
    client.data[brainKey] = {
      value: JSON.stringify({users: {}, _private: {derp: derpValue}})
    }
    listener = new HubotEtcdBrainListener(brainKey, client, robot)
    listener.on 'loaded', ->
      should.exist(robot.brain.get('derp'))
      robot.brain.get('derp').should.eql(derpValue)
      done()
    listener.loadJSON()

  it 'ignores corrupt brain dumps', (done) ->
    derpValue = "#{Math.random()}"
    client.data[brainKey] = {
      value: JSON.stringify({users: {}, _private: {derp: derpValue}})
    }
    listener = new HubotEtcdBrainListener(brainKey, client, robot)
    listener.on 'loaded', ->
      should.exist(robot.brain.get('derp'))
      robot.brain.get('derp').should.eql(derpValue)
      done()
    listener.loadJSON()
